//****************************************************************************
//
//! \copyright 2020 by WinSystems Inc.
//!
//!  Permission is hereby granted to the purchaser of WinSystems CPU products
//!  to distribute any binary file or files compiled using this source code
//!  directly or in any work derived by the user from this file. In no case
//!  may the source code, original or derived from this file, be distributed
//!  to any third party except by explicit permission of WinSystems. This file
//!  is distributed on an "As-is" basis and no warranty as to performance or
//!  fitness of purposes is expressed or implied. In no case shall WinSystems
//!  be liable for any direct or indirect loss or damage, real or consequential
//!  resulting from the usage of this source code. It is the user's sole re-
//!  sponsibility to determine fitness for any considered purpose.
//
//****************************************************************************
//
//! \file      x86_64_port.h
//! \brief     Typeing of standard types to remove any ambiguity about variable
//!            sizes
//
//! \author    pjp
//
//! \version    0.3     10/06/2017      Markup for doxygen
//              0.2     09/07/2017      "ported" to x86_64
//              0.1     06/11/2014      Original
//
//****************************************************************************

#ifndef __86_64_PORT_INC
#define __86_64_PORT_INC

///////////////////////////////////////////////////////////////////////////////

//! \brief      boolean
//typedef unsigned char       bool;

//
//! \brief      pointer to boolean
//typedef bool *  pbool_t;

//
//! \brief      pointer to void
typedef void *  PVOID;

//
//! \brief      pointer to void
typedef void *  pvoid;

//
//! \brief      unsigned 8 bit integer
typedef unsigned char         uint8_t;

//
//! \brief      signed 16 bit integer
typedef          short int    int16_t;

//
//! \brief      unsigned 16 bit integer
typedef unsigned short int    uint16_t;

//
//! \brief      signed 32 bit integer
typedef          int          int32_t;

//
//! \brief      unsigned 32 bit integer
typedef unsigned int          uint32_t;

//
//! \brief      signed 64 bit integer
typedef          long int     int64_t;

//
//! \brief      unsigned 64 bit integer
typedef unsigned long int     uint64_t;

//
//! \brief      pointer to unsigned 8 bit integer
typedef uint8_t  *puint8_t;

//
//! \brief      pointer to unsigned 16 bit integer
typedef uint16_t *puint16_t;

//
//! \brief      pointer to unsigned 32 bit integer
typedef uint32_t *puint32_t;

//
//! \brief      pointer to unsigned 64 bit integer
typedef uint64_t *puint64_t;

//
//! \brief   pointer to signed 8 bit integer
//typedef int8_t   *pint8_t;

//
//! \brief   pointer to signed 16 bit integer
typedef int16_t  *pint16_t;

//
//! \brief   pointer to signed 32 bit integer
typedef int32_t  *pint32_t;

//
//! \brief   pointer to signed 64 bit integer
typedef int64_t  *pint64_t;

//
//! \brief   pointer to float
typedef float    *pfloat_t;

//
//! \brief   pointer to double
typedef double   *pdouble_t;

//
//! \brief some definitions useful for boolean expressions
//
//! \def    true = 1
#define true    1               //!< define "true"
//
//! \def    TRUE = 1
#define TRUE    true            //!< define "TRUE"
//
//! \def    false = 0
#define false   0               //!< define "false"
//
//! \def    FALSE = 0
#define FALSE   false           //!< define "FALSE"
//
//! \def    null = NULL
#define null    NULL            //!< define "null"

#endif