//****************************************************************************
//	
//	Copyright 2020 by WinSystems Inc.
//
//****************************************************************************
//
//	Name	 : libi440.h
//
//	Project	 : PX1-I440-ADC Linux Device Driver
//
//****************************************************************************
//
//	  Date		Revision	                Description
//	--------	--------	---------------------------------------------
//	07/27/20	  1.0		Original Release	
//
//****************************************************************************

#ifndef LIBI440_H
#define LIBI440_H

#ifdef __cplusplus
extern "C"
{
#endif   
     int InitializeSession(void);
     int CloseSession(void);
     int GetFpgaRevision(unsigned int *fpgaVersion);
     int GetSoftwareVersion(unsigned int *pDriverVersion, unsigned int *pLibVersion);
     int SetChannelMode(unsigned int channel, int duplex, int range);
     int SetTimeBase(unsigned int time);
     int GetChannelData(unsigned int *pValue, unsigned int channel);
     int GetChannelDataCount(unsigned char *pValue, unsigned int channel, unsigned int *pCount);
     int GetAllChannelData(unsigned char *pValBuf);
     int GetChannelSequence(unsigned char *pValBuf, unsigned int *pChanSeq);
     int GetChannelSequenceCount(unsigned char *pValBuf, unsigned int *pChanSeq, unsigned int *pCount);
     int ConvertToVolts(float *pVoltage, unsigned int channel, int value);
     int WriteCommands(unsigned char *pValBuf, unsigned char *pCmd, unsigned int cnt);
     int StartSequence(void);
     int StopSequence(void);
     int FlushRxQueue(void);
#ifdef __cplusplus     
}
#endif

enum ErrorCodes {
    SUCCESS = 0,
    DRIVER_ERROR = 1,
    INVALID_HANDLE = 2,
    INVALID_PARAMETER = 3,
    INVALID_SEQUENCE = 4,
    TIMEOUT_ERROR = 5
};

enum AdcChannel {
        ADC_CHAN0 = 0,
        ADC_CHAN1 = 1,
        ADC_CHAN2 = 2,
        ADC_CHAN3 = 3,
        ADC_CHAN4 = 4,
        ADC_CHAN5 = 5,
        ADC_CHAN6 = 6,
        ADC_CHAN7 = 7,
        ADC_NO_CHANNEL = 8
};

enum AdcDuplex {
    ADC_UNIPOLAR = 0,
    ADC_BIPOLAR = 2
};

enum AdcRange {
    ADC_TOP_5V = 0,
        ADC_TOP_5_12V = 1,
        ADC_TOP_10V = 4,
        ADC_TOP_10_24V = 5
};

enum TimeBase {
    TIME_1MHz = 59,
    TIME_500kHz = 119,
    TIME_100kHz = 599,
    TIME_50kHz = 1199,
    TIME_10kHz = 5999,
    TIME_5kHz = 11999,
    TIME_1kHz = 59999,
    TIME_LIMIT = 65533
};

#endif // LIBI440_H
